#[repr(transparent)]pub struct Atlptds(pub u32);Expand description
Skip map for each ATL PTD
Tuple Fields
0: u32Implementations
Sourceimpl Atlptds
impl Atlptds
Sourcepub const fn atl_skip(&self) -> u32
pub const fn atl_skip(&self) -> u32
When a bit in the PTD Skip Map is set to logic 1, the corresponding PTD will be skipped, independent of the V bit setting.
Sourcepub const fn set_atl_skip(&mut self, val: u32)
pub const fn set_atl_skip(&mut self, val: u32)
When a bit in the PTD Skip Map is set to logic 1, the corresponding PTD will be skipped, independent of the V bit setting.