nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Datapayload

Struct Datapayload 

#[repr(transparent)]
pub struct Datapayload(pub u32);
Memory base address that indicates the start of the data payload buffers

Tuple Fields

0: u32

Implementations

Source

impl Datapayload

pub const fn dat_base(&self) -> u16

Base address to be used by the hardware to find the start of the data payload section.

pub const fn set_dat_base(&mut self, val: u16)

Base address to be used by the hardware to find the start of the data payload section.