nxp-pac

Crates

git

Versions

lpc55s69_cm33_core0

Flavors

Intptds

Struct Intptds 

#[repr(transparent)]
pub struct Intptds(pub u32);
Skip map for each INT PTD

Tuple Fields

0: u32

Implementations

Source

impl Intptds

pub const fn int_skip(&self) -> u32

When a bit in the PTD Skip Map is set to logic 1, the corresponding PTD will be skipped, independent of the V bit setting.

pub const fn set_int_skip(&mut self, val: u32)

When a bit in the PTD Skip Map is set to logic 1, the corresponding PTD will be skipped, independent of the V bit setting.