#[repr(transparent)]pub struct Lastptd(pub u32);Expand description
Marks the last PTD in the list for ISO, INT and ATL
Tuple Fields
0: u32Implementations
Sourceimpl Lastptd
impl Lastptd
Sourcepub const fn atl_last(&self) -> u8
pub const fn atl_last(&self) -> u8
If hardware has reached this PTD and the J bit is not set, it will go to PTD0 as the next PTD to be processed.
Sourcepub const fn set_atl_last(&mut self, val: u8)
pub const fn set_atl_last(&mut self, val: u8)
If hardware has reached this PTD and the J bit is not set, it will go to PTD0 as the next PTD to be processed.
Sourcepub const fn set_iso_last(&mut self, val: u8)
pub const fn set_iso_last(&mut self, val: u8)
This indicates the last PTD in the ISO list.
Sourcepub const fn set_int_last(&mut self, val: u8)
pub const fn set_int_last(&mut self, val: u8)
This indicates the last PTD in the INT list.